@@ -27,9 +27,9 @@ class Attribute(object):
         self._unit = "-"
         self._dimension = kwargs.get("dimension", "?")
         self._description = ""
-        self._dtype = "str"
+        self._dtype = None
         self.name = name
-        self.dtype = kwargs.get("dtype", "str")
+        self.dtype = kwargs.get("dtype", None)
         self.description = kwargs.get("description", "")
         self.unit = kwargs.get("unit", "-")
         # set dtype first!
@@ -58,10 +58,10 @@ class Attribute(object):
 
     def _set_value(self, value):
         try:
-            # dtype = self.DTYPES.get(self.dtype, str)
-            dtype = self._guess_dtype(value)
+            dtype = self.DTYPES.get(self.dtype, None)
+            if dtype is None:
+                dtype = self._guess_dtype(value)
             self.dtype = dtype.__name__
-            # print(self.dtype, dtype.__name__)
             if value is None:
                 self._value = None
             elif dtype.__name__ == "bool" and value in [0, "0", "False", "false"]:
@@ -100,7 +100,7 @@ s
         :return:
         """
         if value is None:
-            return "str"
+            return None
         elif "float" in value:
             value = "float"
         elif "int" in value:
@@ -262,12 +262,12 @@ class Metadata(object):
         metadata = cls.from_dict(d)
         return metadata
 
-    def to_csv(self, filepath=None, sep=","):
+    def to_csv(self, filepath=None, sep=",", header=False):
         """serialize to csv"""
         try:
             df = self.to_dataframe()
-            df.to_csv(filepath, index=None, sep=sep)
-            return df.to_csv(filepath, index=None)
+            # df.to_csv(filepath, index=None, sep=sep)
+            return df.to_csv(filepath, index=None, sep=sep, header=header)
         except OSError as exp:
             logging.error("metadata.to_csv error: %s" % (exp))
 
